@@ -1,8 +1,6 @@
 package operator
 
 import (
-	"fmt"
-	"os"
 	"testing"
 
 	appsv1 "k8s.io/api/apps/v1"
@@ -12,7 +10,6 @@ import (
 
 	operatorv1 "github.com/openshift/api/operator/v1"
 	operatorfake "github.com/openshift/client-go/operator/clientset/versioned/fake"
-	"github.com/openshift/cluster-openshift-controller-manager-operator/pkg/util"
 	"github.com/openshift/library-go/pkg/operator/events"
 	operatorv1helpers "github.com/openshift/library-go/pkg/operator/v1helpers"
 )
@@ -23,100 +20,125 @@ func TestProgressingCondition(t *testing.T) {
 		name                        string
 		daemonSetGeneration         int64
 		daemonSetObservedGeneration int64
+		daemonSetNumAvailable       int32
+		daemonSetNumDesired         int32
+		daemonSetNumUpdated         int32
 		configGeneration            int64
 		configObservedGeneration    int64
 		expectedStatus              operatorv1.ConditionStatus
 		expectedMessage             string
-		version                     string
 	}{
 		{
 			name:                        "HappyPath",
 			daemonSetGeneration:         100,
 			daemonSetObservedGeneration: 100,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            100,
 			configObservedGeneration:    100,
 			expectedStatus:              operatorv1.ConditionFalse,
-			version:                     "v1",
 		},
 		{
 			name:                        "DaemonSetObservedAhead",
 			daemonSetGeneration:         100,
 			daemonSetObservedGeneration: 101,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            100,
 			configObservedGeneration:    100,
 			expectedStatus:              operatorv1.ConditionTrue,
 			expectedMessage:             "daemonset/controller-manager: observed generation is 101, desired generation is 100.",
-			version:                     "v1",
 		},
 		{
 			name:                        "DaemonSetObservedBehind",
 			daemonSetGeneration:         101,
 			daemonSetObservedGeneration: 100,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            100,
 			configObservedGeneration:    100,
 			expectedStatus:              operatorv1.ConditionTrue,
 			expectedMessage:             "daemonset/controller-manager: observed generation is 100, desired generation is 101.",
-			version:                     "v1",
 		},
 		{
 			name:                        "ConfigObservedAhead",
 			daemonSetGeneration:         100,
 			daemonSetObservedGeneration: 100,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            100,
 			configObservedGeneration:    101,
 			expectedStatus:              operatorv1.ConditionTrue,
 			expectedMessage:             "openshiftcontrollermanagers.operator.openshift.io/cluster: observed generation is 101, desired generation is 100.",
-			version:                     "v1",
 		},
 		{
 			name:                        "ConfigObservedBehind",
 			daemonSetGeneration:         100,
 			daemonSetObservedGeneration: 100,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            101,
 			configObservedGeneration:    100,
 			expectedStatus:              operatorv1.ConditionTrue,
 			expectedMessage:             "openshiftcontrollermanagers.operator.openshift.io/cluster: observed generation is 100, desired generation is 101.",
-			version:                     "v1",
 		},
 		{
 			name:                        "MultipleObservedAhead",
 			daemonSetGeneration:         100,
 			daemonSetObservedGeneration: 101,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            100,
 			configObservedGeneration:    101,
 			expectedStatus:              operatorv1.ConditionTrue,
 			expectedMessage:             "daemonset/controller-manager: observed generation is 101, desired generation is 100.\nopenshiftcontrollermanagers.operator.openshift.io/cluster: observed generation is 101, desired generation is 100.",
-			version:                     "v1",
 		},
 		{
 			name:                        "ConfigAndDaemonSetGenerationMismatch",
 			daemonSetGeneration:         100,
 			daemonSetObservedGeneration: 100,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            101,
 			configObservedGeneration:    101,
 			expectedStatus:              operatorv1.ConditionFalse,
-			version:                     "v1",
 		},
 		{
-			name:                        "UpgradeInProgressVersionMissing",
+			name:                        "NoneAvailable",
 			daemonSetGeneration:         100,
 			daemonSetObservedGeneration: 100,
+			daemonSetNumAvailable:       0,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         3,
 			configGeneration:            100,
 			configObservedGeneration:    100,
 			expectedStatus:              operatorv1.ConditionTrue,
-			expectedMessage:             fmt.Sprintf("daemonset/controller-manager: version annotation %s missing.", util.VersionAnnotation),
+			expectedMessage:             "daemonset/controller-manager: number available is 0, desired number available > 1",
+		},
+		{
+			name:                        "UpgradeInProgress",
+			daemonSetGeneration:         100,
+			daemonSetObservedGeneration: 100,
+			daemonSetNumAvailable:       3,
+			daemonSetNumDesired:         3,
+			daemonSetNumUpdated:         2,
+			configGeneration:            100,
+			configObservedGeneration:    100,
+			expectedStatus:              operatorv1.ConditionTrue,
+			expectedMessage:             "daemonset/controller-manager: updated number scheduled is 2, desired number scheduled is 3",
 		},
 	}
 
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
 
-			if len(tc.version) > 0 {
-				os.Setenv("RELEASE_VERSION", tc.version)
-			} else {
-				os.Unsetenv("RELEASE_VERSION")
-			}
-
 			kubeClient := fake.NewSimpleClientset(
 				&corev1.Secret{ObjectMeta: metav1.ObjectMeta{Name: "serving-cert", Namespace: "openshift-controller-manager"}},
 				&corev1.Secret{ObjectMeta: metav1.ObjectMeta{Name: "etcd-client", Namespace: "kube-system"}},
@@ -127,8 +149,11 @@ func TestProgressingCondition(t *testing.T) {
 						Generation: tc.daemonSetGeneration,
 					},
 					Status: appsv1.DaemonSetStatus{
-						NumberAvailable:    100,
-						ObservedGeneration: tc.daemonSetObservedGeneration,
+						NumberAvailable:        tc.daemonSetNumAvailable,
+						CurrentNumberScheduled: tc.daemonSetNumDesired,
+						DesiredNumberScheduled: tc.daemonSetNumDesired,
+						UpdatedNumberScheduled: tc.daemonSetNumUpdated,
+						ObservedGeneration:     tc.daemonSetObservedGeneration,
 					},
 				})
 
